dival package
=============

Subpackages
-----------

.. toctree::

   dival.datasets
   dival.reconstructors
   dival.util

Submodules
----------

.. toctree::

   dival.config
   dival.data
   dival.evaluation
   dival.hyper_param_search
   dival.measure

Module contents
---------------

.. automodule:: dival
   :members:
   :undoc-members:
   :show-inheritance:
